#!/bin/bash

script_dir=$(dirname "${BASH_SOURCE[0]}")
source "${script_dir}/helpers/helm_helpers.sh"

k3d cluster create distribution \
    --agents 2 \
    --servers 1 \
    --api-port 0.0.0.0:6551 \
    --k3s-arg "--disable=traefik@server:0" \
    --k3s-arg "--flannel-backend=none@server:*" \
    --k3s-arg "--cluster-cidr=${CLUSTER_CIDR}@server:*" \
    --k3s-arg "--disable-network-policy@server:*" \
    --image "rancher/k3s:v${K3S_VERSION}-k3s1" \
    --port "80:80@loadbalancer" \
    --port "443:443@loadbalancer" \
    --port "2222:22@loadbalancer" \
    --kubeconfig-update-default=true \
    --kubeconfig-switch-context=true

# install calico
calico_dir="/tmp/calico"
git clone https://git.420joos.dev/kubernetes-cluster/networking/calico.git "${calico_dir}"

calico_repo_name="projectcalico"
add_helm_repo ${calico_repo_name} https://docs.tigera.io/calico/charts
install_helm_chart calico \
    ${calico_repo_name} \
    tigera-operator \
    "${CALICO_VERSION:-v3.29.2}" \
    tigera-operator \
    5m \
    "${calico_dir}/values.yaml" \
    "--set installation.calicoNetwork.ipPools[0].cidr=${CLUSTER_CIDR}"

remove_helm_repo ${calico_repo_name}
rm -rf "${calico_dir}"

# install gitlab agent
install_gitlab_agent \
    "${GITLAB_AGENT_CHART_VERSION:-2.7.2}" \
    "https://git.420joos.dev/kubernetes-cluster/gitlab/runners/kubernetes-agent.git" \
    "values.yaml" \
    "${GITLAB_AGENT_IMAGE_VERSION:-17.4.1}" \
    "${GITLAB_AGENT_TOKEN}"
