add_helm_repo() {
    repo_name=$1
    repo_url=$2

    helm repo add ${repo_name} ${repo_url}
    helm repo update
}

remove_helm_repo() {
    repo_name=$1

    helm repo remove ${repo_name}
}

install_helm_chart() {
    deployment_name=$1
    repo_name=$2
    chart_name=$3
    chart_version=$4
    namespace=$5
    timeout=$6
    values_files=$7
    upgrade_args=$8
    
    values_arg=""
    for values_file in $values_files; do
        values_arg="${values_arg} --values ${values_file}"
    done
    helm upgrade ${deployment_name} ${repo_name}/${chart_name} \
        --install \
        --version ${chart_version} \
        --namespace ${namespace} \
        --create-namespace \
        --timeout ${timeout} \
        --wait \
        ${values_arg} \
        ${upgrade_args}
}

install_gitlab_agent() {
    chart_version=$1
    git_repo_url=$2
    values_filenames=$3
    image_version=$4
    token=$5

    repo_name="gitlab"
    chart_name="gitlab-agent"
    namespace="gitlab-agents"
    
    git_repo_dir="/tmp/gitlab-agent"
    values_files=""
    for filename in $values_filenames; do
        values_files="${values_files} ${git_repo_dir}/${filename}"
    done

    upgrade_args="--set image.tag=v${image_version} --set config.token=${token}"

    git clone "${git_repo_url}" "${git_repo_dir}"

    add_helm_repo ${repo_name} https://charts.gitlab.io
    install_helm_chart distribution-agent ${repo_name} ${chart_name} ${chart_version} ${namespace} 5m "${values_files}" "${upgrade_args}"
    remove_helm_repo ${repo_name}
    
    rm -rf "${git_repo_dir}"
}
